@@ -1,8 +1,8 @@
 
-__version__ = "2.2"
+__version__ = "4.5"
 docs = r"https://crocodile.readthedocs.io/en/latest/"
 git = r"https://github.com/thisismygitrepo/crocodile"
 release_notes = """
 
-Fixed deep learning problems
+Added Log and Frdige classes.
 """
